@@ -1,19 +1,25 @@
-"boa.chain.eval" <-
-function(expr, pname)
+"boa.chain.eval" <- function(expr, pname)
 #-------------------------------------------------------------------------------
 #-------------------------------------------------------------------------------
 {
+   success <- TRUE
+   
    master <- boa.chain("master")
    master.support <- boa.chain("master.support")
    for(i in names(master)) {
+      x <- try(eval(expr, as.data.frame(master[[i]])), TRUE)
+      if(inherits(x, "try-error")) {
+         success <- FALSE
+         cat(x)
+         break
+      }
       pnames <- boa.pnames(master[[i]])
       if(is.element(pname, pnames)) {
-         cat("Warning: found ", pname, " in ", i, "; skipping chain\n",
-             sep = "")
+         master[[i]][, pname] <- x
+         master.support[[i]][, pname] <- c(-Inf, Inf)
       } else {
          pnames <- c(pnames, pname)
-         master[[i]] <- cbind(master[[i]],
-                              eval(expr, as.data.frame(master[[i]])))
+         master[[i]] <- cbind(master[[i]], x)
          dimnames(master[[i]])[[2]] <- pnames
          master.support[[i]] <- cbind(master.support[[i]], c(-Inf, Inf))
          dimnames(master.support[[i]])[[2]] <- pnames
@@ -25,5 +31,6 @@ function(expr, pname)
    } else {
       boa.chain(master = master, master.support = master.support)
    }
-   invisible()
+   
+   invisible(success)
 }
