@@ -24,18 +24,22 @@ function(lnames, pname, annotate = boa.par("legend"))
    }
    drawn <- k > 0
    if(drawn) {
+      val <- boa.par("par")
+      cex <- ifelse(is.null(val$cex), 1, val$cex)
+      lwd <- ifelse(is.null(val$lwd), 1, val$lwd)
       plot(xlim, ylim, xlab = "Iteration", ylab = pname,
            xlim = xlim, ylim = ylim, type = "n")
       k <- 0
       for(i in lnames) {
          for(j in ipname[[i]]) {
             k <- k + 1
-            lines(boa.iter(work[[i]]), ybar[[k]], lty = k)
+            lines(boa.iter(work[[i]]), ybar[[k]], lty = k, lwd = lwd)
          }
       }
       if(annotate)
          legend(x = xlim[2], y = ylim[2], xjust = 1, yjust = 1,
-                legend = key.names, lty = 1:k, bty = "n")
+                legend = key.names, lty = 1:k, bty = "n",
+                cex = cex, lwd = lwd)
    }
 
    return(drawn)
